@@ -1,5 +1,5 @@
 package Text::Hogan::Template;
-$Text::Hogan::Template::VERSION = '0.05';
+$Text::Hogan::Template::VERSION = '0.06';
 use strict;
 use warnings;
 
@@ -40,13 +40,15 @@ sub r {
 
 sub v {
     my ($self, $str) = @_;
-    $str = $self->t($str);
+    $str = defined($str) ? $str : "";
 
-    $str =~ s/&/&amp;/g;
-    $str =~ s/</&lt;/g;
-    $str =~ s/>/&gt;/g;
-    $str =~ s/'/&#39;/g;
-    $str =~ s/"/&quot;/g;
+    if ($str =~ m{[&<>'"]}) {
+        $str =~ s/&/&amp;/g;
+        $str =~ s/</&lt;/g;
+        $str =~ s/>/&gt;/g;
+        $str =~ s/'/&#39;/g;
+        $str =~ s/"/&quot;/g;
+    }
 
     return $str;
 }
@@ -261,14 +263,16 @@ sub f {
 
 # higher order templates
 sub ls {
-    my ($self, $func, $cx, $ctx, $partials, $text, $tags) = @_;
-    my $old_tags = $self->{'options'}{'delimiters'};
+    die "Higher Order Templates Not Supported Yet!\n";
 
-    $self->{'options'}{'delimiters'} = $tags;
-    $self->b($self->ct(coerce_to_string($func->($self,$cx,$text,$ctx)), $cx, $partials));
-    $self->{'options'}{'delimiters'} = $old_tags;
-
-    return 0;
+#   my ($self, $func, $cx, $ctx, $partials, $text, $tags) = @_;
+#   my $old_tags = $self->{'options'}{'delimiters'};
+#
+#   $self->{'options'}{'delimiters'} = $tags;
+#   $self->b($self->ct(coerce_to_string($func->($self,$cx,$text,$ctx)), $cx, $partials));
+#   $self->{'options'}{'delimiters'} = $old_tags;
+#
+#   return 0;
 }
 
 # compile text
@@ -295,24 +299,25 @@ sub fl {
 
 # method replace section
 sub ms {
-    my ($self, $func, $ctx, $partials, $inverted, $start, $end, $tags) = @_;
-    my $text_source;
-    my $cx = $ctx->[-1];
-    my $result = $func->($self, $cx);
-
-    if (ref($result) eq 'CODE') {
-        if ($inverted) {
-            return 1;
-        }
-        else {
-            $text_source = ($self->{'active_sub'} && $self->{'subs_text'} && $self->{'subs_text'}{$self->{'active_sub'}})
-                ? $self->{'subs_text'}{$self->{'active_sub'}}
-                : $self->{'text'};
-            return $self->ls($result, $cx, $ctx, $partials, substr($text_source,$start,$end), $tags);
-        }
-    }
-
-    return $result;
+    die "Lambda Sections Not Supported Yet!\n";
+#   my ($self, $func, $ctx, $partials, $inverted, $start, $end, $tags) = @_;
+#   my $text_source;
+#   my $cx = $ctx->[-1];
+#   my $result = $func->($self, $cx);
+#
+#   if (ref($result) eq 'CODE') {
+#       if ($inverted) {
+#           return 1;
+#       }
+#       else {
+#           $text_source = ($self->{'active_sub'} && $self->{'subs_text'} && $self->{'subs_text'}{$self->{'active_sub'}})
+#               ? $self->{'subs_text'}{$self->{'active_sub'}}
+#               : $self->{'text'};
+#           return $self->ls($result, $cx, $ctx, $partials, substr($text_source,$start,$end), $tags);
+#       }
+#   }
+#
+#   return $result;
 }
 
 # method replace variable
@@ -408,7 +413,7 @@ Text::Hogan::Template - represent and render compiled templates
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
